busy_widget — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# busy_widget

class `camelot.view.controls.busy_widget.` `BusyWidget`(parent=None)

  A widget indicating the application is performing some background task. The widget acts as an overlay of its parent widget and displays animating orbs

  `paintEvent`(event)

    custom paint, painting the orbs

  `set_busy`(busy_state)

    start/stop the animation :arg busy_state: True or False

  `timerEvent`(event)

    custom timer event, updating the animation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus